/*
 * EFL Profiling Viewer
 * Copyright (C) 2017 Samsung Electronics.
 *
 * This file is part of EFL Profiling Viewer.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; If not, see www.gnu.org/licenses/lgpl.html.
 */

#ifndef _EFL_PROFILER_H
#define _EFL_PROFILER_H

#include <Elementary.h>

#ifdef EAPI
# undef EAPI
#endif

#ifdef _WIN32
# ifdef EFL_PROFILER_BUILD
#  ifdef DLL_EXPORT
#   define EAPI __declspec(dllexport)
#  else
#   define EAPI
#  endif /* ! DLL_EXPORT */
# else
#  define EAPI __declspec(dllimport)
# endif /* ! EFL_PROFILER_BUILD */
#else
# ifdef __GNUC__
#  if __GNUC__ >= 4
#   define EAPI __attribute__ ((visibility("default")))
#  else
#   define EAPI
#  endif
# else
#  define EAPI
# endif
#endif /* ! _WIN32 */

typedef struct _Time_Range Time_Range;
typedef struct _Stream_Block_Data Stream_Block_Data;

/**
 * @typedef Time_Range
 *
 * This struct represents time intervals
 *
 */
struct _Time_Range
{
   double start;  /**< Offset value in seconds from beginning of events in log */
   double length; /**< Duration of this time interval in seconds               */
};
#define DEFAULT_START_RANGE {2, 1}

struct _Stream_Block_Data
{
   unsigned int size;
   void *data;
};

EAPI Evas_Object *
efl_profiling_viewer_init(Evas_Object *parent);

EAPI Eina_Bool
efl_profiling_viewer_shutdown(Evas_Object* content);

#endif
